==> cscec5b-storecloud-impl-3.0.1-20220819.082352-66-sources.jar: com/ejianc/business/storecloud/service/impl/PersionProjectServiceImpl.java <==
package com.ejianc.business.storecloud.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.storecloud.bean.PersionProjectEntity;
import com.ejianc.business.storecloud.mapper.PersionProjectMapper;
import com.ejianc.business.storecloud.service.IPersionProjectService;
import com.ejianc.business.storecloud.utils.MD5Utils;
import com.ejianc.business.storecloud.vo.PersionProjectVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.UUID;

/**
 * 领料人员
 *
 * @author generator
 *
 */
@Service("persionProjectService")
public class PersionProjectServiceImpl extends BaseServiceImpl<PersionProjectMapper, PersionProjectEntity> implements IPersionProjectService {

    @Override
    public String resetPasswords(PersionProjectVO vos) {
        String[] chars = new String[] { "a", "b", "c", "d", "e", "f",
                "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s",
                "t", "u", "v", "w", "x", "y", "z", "0", "1", "2", "3", "4", "5",
                "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I",
                "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V",
                "W", "X", "Y", "Z" };
        StringBuffer shortBuffer = new StringBuffer();
        String uuid = UUID.randomUUID().toString().replace("-", "");
        for (int i = 0; i < 8; i++) {
            String str = uuid.substring(i * 4, i * 4 + 4);
            int x = Integer.parseInt(str, 16);
            shortBuffer.append(chars[x % 0x3E]);
        }
        String suffix = shortBuffer.toString();
        //更新用户密码
        LambdaUpdateWrapper<PersionProjectEntity>updateWrapper=new LambdaUpdateWrapper<>();
        updateWrapper.set(PersionProjectEntity::getUserPwd, MD5Utils.getStringMD5(MD5Utils.getStringMD5(suffix)));
        updateWrapper.eq(PersionProjectEntity::getId, vos.getId());
        this.update(updateWrapper);
        return suffix;
    }

    @Override
    public void updatePwd(PersionProjectVO persionProjectVO) {
        if(StringUtils.isBlank(persionProjectVO.getOpenId())){
            throw new BusinessException("openid为空！");
        }
        LambdaUpdateWrapper<PersionProjectEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(PersionProjectEntity::getOpenId, persionProjectVO.getOpenId());
        updateWrapper.set(PersionProjectEntity::getFirstFlag, false);
        updateWrapper.set(PersionProjectEntity::getUserPwd, MD5Utils.getStringMD5(persionProjectVO.getUserPwd()));
        update(updateWrapper);
    }
}

==> cscec5b-storecloud-impl-3.0.1-20220914.110744-176-sources.jar: com/ejianc/business/storecloud/service/impl/PersionProjectServiceImpl.java <==
package com.ejianc.business.storecloud.service.impl;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.storecloud.bean.PersionProjectEntity;
import com.ejianc.business.storecloud.mapper.PersionProjectMapper;
import com.ejianc.business.storecloud.service.IPersionProjectService;
import com.ejianc.business.storecloud.utils.MD5Utils;
import com.ejianc.business.storecloud.vo.PersionProjectVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.UUID;

/**
 * 领料人员
 *
 * @author generator
 *
 */
@Service("persionProjectService")
public class PersionProjectServiceImpl extends BaseServiceImpl<PersionProjectMapper, PersionProjectEntity> implements IPersionProjectService {

    @Override
    public String resetPasswords(PersionProjectVO vos) {
       /* String[] chars = new String[] { "a", "b", "c", "d", "e", "f",
                "g", "h", "i", "j", "k", "l", "m", "n", "o", "p", "q", "r", "s",
                "t", "u", "v", "w", "x", "y", "z", "0", "1", "2", "3", "4", "5",
                "6", "7", "8", "9", "A", "B", "C", "D", "E", "F", "G", "H", "I",
                "J", "K", "L", "M", "N", "O", "P", "Q", "R", "S", "T", "U", "V",
                "W", "X", "Y", "Z" };
        StringBuffer shortBuffer = new StringBuffer();
        String uuid = UUID.randomUUID().toString().replace("-", "");
        for (int i = 0; i < 8; i++) {
            String str = uuid.substring(i * 4, i * 4 + 4);
            int x = Integer.parseInt(str, 16);
            shortBuffer.append(chars[x % 0x3E]);
        }*/
        String suffix = "1234Qwer";
        //更新用户密码
        LambdaUpdateWrapper<PersionProjectEntity>updateWrapper=new LambdaUpdateWrapper<>();
        updateWrapper.set(PersionProjectEntity::getUserPwd, MD5Utils.getStringMD5(MD5Utils.getStringMD5("1234Qwer")));
        updateWrapper.eq(PersionProjectEntity::getId, vos.getId());
        this.update(updateWrapper);
        return suffix;
    }

    @Override
    public void updatePwd(PersionProjectVO persionProjectVO) {
        if(StringUtils.isBlank(persionProjectVO.getOpenId())){
            throw new BusinessException("openid为空！");
        }
        LambdaUpdateWrapper<PersionProjectEntity> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(PersionProjectEntity::getOpenId, persionProjectVO.getOpenId());
        updateWrapper.set(PersionProjectEntity::getFirstFlag, false);
        updateWrapper.set(PersionProjectEntity::getUserPwd, MD5Utils.getStringMD5(persionProjectVO.getUserPwd()));
        update(updateWrapper);
    }
}
